Learn R Programming

spGARCH (version 0.2.3)

residuals.spARCH: Extract model residuals

Description

The function extracts the residuals of a fitted spatial ARCH model.

Usage

## S3 method for class 'spARCH'
# S3 method for spARCH
residuals(object, ...)

Arguments

object

spARCH object generated by qml.spARCH or qml.SARspARCH.

...

Other arguments.

Author

Philipp Otto philipp.otto@glasgow.ac.uk

Details

The function extracts the residuals of a fitted spatial ARCH model.

See Also

residuals.spARCH, fitted.spARCH.